<?php

declare(strict_types=1);

namespace Drupal\search_api_arbitrary_facet\Plugin\ArbitraryFacet;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\search_api_arbitrary_facet\Attribute\ArbitraryFacet;
use Drupal\search_api_arbitrary_facet\Plugin\ArbitraryFacetBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides supports for facets generated by arbitrary queries.
 */
#[ArbitraryFacet(
  id: "default",
  label: new TranslatableMarkup("Default arbitrary query"),
)]
class DefaultArbitraryFacet extends ArbitraryFacetBase implements ContainerFactoryPluginInterface {

  public function __construct(
    array $configuration,
    string $plugin_id,
    mixed $plugin_definition,
    protected readonly AccountProxyInterface $currentUser,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFacetDefinition(): array {
    return [
      'mine' => [
        'field_name' => 'entity_author',
        'field_condition' => $this->currentUser->id(),
        'label' => $this->t("My content"),
      ],
      'featured' => [
        'field_name' => 'site_featured',
        'field_condition' => 'true',
        'label' => $this->t("Featured content"),
      ],
      'collections' => [
        'field_name' => 'entity_bundle',
        'field_condition' => 'collection',
        'label' => $this->t("Collections"),
      ],
    ];
  }

}
